Documentation
¶
Overview ¶
Package xerrors extends the errors package from the standard library.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Must ¶
func Must(err error)
Must panics if the given error is non-nil. It can wrap a call to a function that returns error.
func Must2 ¶ added in v0.3.0
Must2 returns its first passed argument or panics if the second one is non-nil error. It can wrap a call to a function that returns (T, error).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.