xerrors

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2026 License: MIT Imports: 0 Imported by: 0

README

xerrors

Go Reference MIT License Build Status Code Coverage

Installation

go get github.com/ergosit/xerrors

License

This package is licensed under the terms of the MIT License (see LICENSE file).

Documentation

Overview

Package xerrors extends the errors package from the standard library.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Must

func Must[T any](value T, err error) T

Must returns its first passed argument or panics if the second one is non-nil error. It can wrap a call to a function that returns (T, error).

Types

This section is empty.

Jump to